========================
Ironic-lib Documentation
========================

Ironic-lib is a library for use by projects under Bare Metal governance only.
This documentation is intended for developer use only. If you are looking for
documentation for deployers, please see the
`ironic documentation <https://docs.openstack.org/ironic/latest/admin/>`_.

.. toctree::
   :maxdepth: 1

   Installation and Usage documentation <contributor/index>
   reference/index

* :ref:`genindex`
* :ref:`search`
